summaryrefslogtreecommitdiffstats
path: root/src/server/Driver.hpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/server/Driver.hpp')
-rw-r--r--src/server/Driver.hpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/server/Driver.hpp b/src/server/Driver.hpp
index e038b2bc..e5c62623 100644
--- a/src/server/Driver.hpp
+++ b/src/server/Driver.hpp
@@ -34,7 +34,7 @@ class EnginePort;
/** Engine driver base class.
*
- * A Driver is, from the perspective of GraphObjects (blocks, patches, ports)
+ * A Driver is, from the perspective of GraphObjects (blocks, graphs, ports)
* an interface for managing system ports. An implementation of Driver
* basically needs to manage EnginePorts, and handle writing/reading data
* to/from them.
@@ -54,12 +54,12 @@ public:
/** Create a port ready to be inserted with add_input (non realtime).
* May return NULL if the Driver can not create the port for some reason.
*/
- virtual EnginePort* create_port(DuplexPort* patch_port) = 0;
+ virtual EnginePort* create_port(DuplexPort* graph_port) = 0;
/** Find a system port by path. */
virtual EnginePort* get_port(const Raul::Path& path) = 0;
/** Add a system visible port (e.g. a port on the root patch). */
virtual void add_port(ProcessContext& context, EnginePort* port) = 0;
/** Remove a system visible port.
@@ -54,12 +54,12 @@ public:
/** Find a system port by path. */
virtual EnginePort* get_port(const Raul::Path& path) = 0;
- /** Add a system visible port (e.g. a port on the root patch). */
+ /** Add a system visible port (e.g. a port on the root graph). */
virtual void add_port(ProcessContext& context, EnginePort* port) = 0;
/** Remove a system visible port.